<?php
/*
 * Plugin Name: Gallerix
 * Description: Image Gallery Plugin
 * Author: Eightyclouds
 * Version: 2.0
 * Author URI: http://eightyclouds.com
 */
defined("DS")            ? NULL : define("DS", DIRECTORY_SEPARATOR);
defined("GALLERIX_FILE") ? NULL : define("GALLERIX_FILE", __FILE__);

/* Include Gallerix Class */
require_once(dirname(__FILE__) . DS . "admin" . DS . "class" . DS . "gallerix.php");



/* ====================================================
 * INSTALLATION
 * ==================================================== */

/* Install */
function gallerix_activate() {
    require_once(dirname(__FILE__) . DS . "install.php");
}
register_activation_hook(__FILE__, "gallerix_activate");

/* Uninstall */
function gallerix_uninstall() {
    require_once(dirname(__FILE__) . DS . "uninstall.php");
}
register_uninstall_hook(__FILE__, "gallerix_uninstall");



    
    
/* ====================================================
 * New Media Thumbnail Size
 * ==================================================== */
add_action("after_setup_theme", "gallerix_addthumbsize");

function gallerix_addthumbsize() {
    if (function_exists('add_image_size')) {
        add_image_size('gallerix-thumb', 240, 170, true);

        add_filter('image_size_names_choose', 'gallerix_thumbnail');
        function gallerix_thumbnail($sizes) {
            $addsizes = array(
                "gallerix-thumb" => __("Gallerix Thumbnail", "gallerix")
            );
            $newsizes = array_merge($sizes, $addsizes);
            return $newsizes;
        }
    }
}












/* ====================================================
 * Admin Styles and Scripts
 * ==================================================== */

function gallerix_admin_styles() {
    wp_enqueue_style('gallerix-admin-style', plugins_url( 'admin/css/style.css', __FILE__ ));
}

function gallerix_admin_scripts() {
    wp_enqueue_media();
    wp_enqueue_style("colorpicker_style", plugins_url("/admin/js/colorpicker/css/colorpicker.css", __FILE__));
    wp_enqueue_script("colorpicker_js",  plugins_url("/admin/js/colorpicker/js/colorpicker.js", __FILE__),array("jquery"));
    wp_enqueue_script('gallerix-admin-js', plugins_url( 'admin/js/admin.js', __FILE__ ));
        
}





/* ====================================================
 * Generate CSS
 * ==================================================== */

function gallerix_general_settings_styles() {
    $options = Gallerix::get_options();
    echo "<style>";
    
    if ($options->gloss == "0") {
        echo ".Gallerix .gallerix_image_shining { background-image: none;}";
    }
    
    if ($options->shadow == "0") {
        echo ".Gallerix .gallerix_image_box { -webkit-box-shadow:none; box-shadow:none; }";
    }
  
    echo ".Gallerix .gallerix_image_box img { background-color: ".$options->boxbg." }";
    
    echo ".Gallerix .gallerix_top_navigation a { color: ".$options->navcolor." }";
    echo ".Gallerix .gallerix_top_navigation a:hover { color: ".$options->navcolorhover." }";
    echo ".Gallerix .gallerix_top_navigation li.active a { color: ".$options->navcolorhover." }";
    
    echo ".Gallerix .gallerix_pagination li a { color: ".$options->navcolor." }";
    echo ".Gallerix .gallerix_pagination li a:hover { color: ".$options->navcolorhover." }";
    echo ".Gallerix .gallerix_pagination li.active a { color: ".$options->navcolorhover." }";
    
    echo ".Gallerix .gallerix_top_navigation ul {text-align: ".$options->navpos."}";
    echo ".Gallerix .gallerix_pagination ul {text-align: ".$options->navpos."}";
        
    echo "</style>";
}






/* ====================================================
 * Admin Menu
 * ==================================================== */

/* Register Admin Menu */
function register_gallerix_admin_menu_page() {
    
   global $wp_version;
   $ico = $wp_version >= 3.8 ? "dashicons-screenoptions" : plugins_url("admin/img/admin_ico.png", __FILE__);
    
   $page = 'gallerix/admin/view/home/index.php';
   add_utility_page('gallerix', 'Gallerix', 'update_plugins', $page, '',  $ico, 6);
   add_action('admin_print_styles-'  . $page, 'gallerix_admin_styles');
   add_action('admin_print_scripts-'  . $page, 'gallerix_admin_scripts');
}
add_action('admin_menu', 'register_gallerix_admin_menu_page');

/* General sub-menu */
function register_gallerix_admin_submenu_page_general() {
    $page = 'gallerix/admin/view/general/index.php';
    add_submenu_page('gallerix/admin/view/home/index.php', 'Gallerix - General', 'General', 'update_plugins', $page);
    add_action('admin_print_styles-'  . $page, 'gallerix_admin_styles');
    add_action('admin_print_scripts-'  . $page, 'gallerix_admin_scripts');
}
add_action('admin_menu', 'register_gallerix_admin_submenu_page_general');

/* Categories sub-menu */
function register_gallerix_admin_submenu_page_categories() {
    $page = 'gallerix/admin/view/categories/index.php';
    add_submenu_page('gallerix/admin/view/home/index.php', 'Gallerix - Categories', 'Categories', 'update_plugins', $page);
    add_action('admin_print_styles-'  . $page, 'gallerix_admin_styles');
    add_action('admin_print_scripts-'  . $page, 'gallerix_admin_scripts');
}
add_action('admin_menu', 'register_gallerix_admin_submenu_page_categories');

/* Images sub-menu */
function register_gallerix_admin_submenu_page_images() {
    $page = 'gallerix/admin/view/images/index.php';
    add_submenu_page('gallerix/admin/view/home/index.php', 'Gallerix - Images', 'Images', 'update_plugins', $page);
    add_action('admin_print_styles-'  . $page, 'gallerix_admin_styles');
    add_action('admin_print_scripts-'  . $page, 'gallerix_admin_scripts');
}
add_action('admin_menu', 'register_gallerix_admin_submenu_page_images');








/* ====================================================
 * AJAX Handling
 * ==================================================== */

function gallerix_ajaxurl() {
?>
    <script type="text/javascript">
        if (typeof ajaxurl === "undefined") 
        var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
    </script>
<?php
}
add_action('wp_head', 'gallerix_ajaxurl');

function gallerix_getImages() {
    ob_start();
    require(dirname(__FILE__) . DS . "site" . DS . "view" . DS . "ajax.php");
    ob_get_flush();
    die();
}
add_action('wp_ajax_nopriv_getImages', 'gallerix_getImages');
add_action('wp_ajax_getImages', 'gallerix_getImages');








/* ====================================================
 * FONT-END, Shortcode [gallerix]
 * ==================================================== */

function gallerix_check_for_shortcode() {
        global $post;
        if (has_shortcode($post->post_content, 'gallerix')) {
            Gallerix::enqueue_scripts();
        }
    }

add_action('wp_enqueue_scripts', 'gallerix_check_for_shortcode');

function gallerix_display($gallerix_args = array()) {
    $unique = Gallerix::unique();
    
    /* Double check scripts */
    Gallerix::enqueue_scripts(); 
    
    ob_start();
    require(dirname(__FILE__) . DS . "site" . DS . "view" . DS . "display.php");
    return ob_get_clean();
}
add_shortcode("gallerix", "gallerix_display");

